# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Expect
Version:	1.38
Release:	1.%{__distinit}%{__distvers}
Summary:	Expect for Perl
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Expect
Source0:	https://cpan.metacpan.org/modules/by-module/Expect/Expect-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IO::Pty) >= 1.11
BuildRequires:	perl(IO::Tty) >= 1.11
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More) >= 0.98
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module provides Expect-like functionality to Perl. Expect is
a tool for automating interactive applications such as telnet, ftp,
passwd, fsck, rlogin, tip, etc.

%prep
%setup -q -n Expect-%{version}
sed -i 's|^#!/usr/local/bin/perl|#!/usr/bin/perl|' examples/kibitz/kibitz tutorial/[2-6].*
chmod -c a-x Changes examples/*.pl examples/kibitz/* lib/Expect.pm LICENSE README.md tutorial/*

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README.md examples/ tutorial/
%{perl_vendorlib}/Expect.pm
%{_mandir}/man3/Expect.3*

%changelog
* Tue Mar 12 2024 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38
  - Fix to fix to timeout code

* Fri Mar  8 2024 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37
  - Fix to timeout code

* Sat Feb 24 2024 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - Made timeouts optional and added qr// regex support

* Sat Apr  8 2023 Paul Howarth <paul@city-fan.org> - 1.35-20
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop support for building with ExtUtils::MakeMaker < 6.64

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 1.35-12
- Perl 5.32 rebuild

* Fri May 19 2017 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35
  - Official maintainer JACOBY (Dave Jacoby)
  - Added a MANIFEST so that "make dist" will work
  - Added AUTHOR key, listing all maintainers
- Add patch to support building with old versions of ExtUtils::MakeMaker
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.98

* Mon Jun 13 2016 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33
  - Remove dependency on Test::Exception
- This release by JACOBY → update source URL
- BR: perl-generators where available
- Package new LICENSE file

* Sun Oct 26 2014 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32
  - Skip bc tests (CPAN RT#98495)
- Classify buildreqs by usage

* Fri Sep  5 2014 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - New co-maintainer (Gabor Szabo)
  - Merge .pod and .pm and move them to lib/
  - Move the test and the code to standard location /t in the distribution
  - Eliminate indirect calls in tests
  - Use Test::More instead of home-brew testing
  - Typos fixed in pod (CPAN RT#86852)
  - Changes file re-ordered and standardized
  - Refactored test script
  - Eliminate indirect calls in the code and in the docs
  - Use Perl::Tidy to unify layout
  - Added use warnings;
  - IO::Tty prerequisite version 1.03 → 1.11
  - More test diagnostics
  - Tests added for CPAN RT#62359
  - Skip the bc test on OS-es where it has been failing
  - Stop inheriting from Exporter
  - Eliminate $` and $' from the code (part of CPAN RT#61395); this fix might
    break some existing code in some extreme cases when the regex being matched
    has a lookbehind or a lookahead at the edges
  - Remove $& and $`, fixing the rest of CPAN RT#61395
  - Various code refactoring declaring loop variables, parameter passing,
    return undef, etc.
  - Croak if undef passed to _trim_length
  - Update documentation according to CPAN RT#60722
  - CPAN RT#47834: after a failed call to ->expect, the ->match and ->after
    will return undef and ->before will return the content of the accumulator;
    earlier they retained the values obtained during the last successful match
    (->before will return undef the first time but later, if we call
    ->clear_accum, it will start returning the empty string)
  - In the tests, add special treatment for $^O=midnightbsd and dragonfly, and
    for $^O=linux as well
  - Test t/11-calc.t also got some special treatment
- This release by SZABGAB → update source URL
- We need Test::More ≥ 0.98, so use a bundled one if we don't have it

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.21-18
- Drop %%defattr, redundant since rpm 4.4

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 1.21-12
- Drop BR: perl(Errno), perl(Fcntl) and perl(POSIX) - not dual-lived
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jan 23 2012 Paul Howarth <paul@city-fan.org> - 1.21-11
- BR: perl(Carp), perl(Errno), perl(Exporter), perl(Fcntl), perl(IO::Handle)
  and perl(POSIX)

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 1.21-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.21-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.21-5
- Fix dist tag for RHEL-6 Beta

* Sun Feb 21 2010 Paul Howarth <paul@city-fan.org> - 1.21-4
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Sep 10 2009 Paul Howarth <paul@city-fan.org> - 1.21-3
- Define RPM macros in global scope

* Fri Nov 14 2008 Paul Howarth <paul@city-fan.org> - 1.21-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Mark pod as %%doc

* Tue Aug 14 2007 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Fri Jul 13 2007 Paul Howarth <paul@city-fan.org> - 1.20-2
- Import from Fedora
- Fix argument order for find with -depth

* Fri Jul 21 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.20-1
- Update to 1.20

* Tue Jul 18 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.19-1
- Update to 1.19

* Tue Jul 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.18-1
- Update to 1.18

* Wed May 31 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.17-1
- Update to 1.17

* Tue May 16 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.16-2
- Description improved as suggested in #191622

* Mon May 08 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.16-1
- First build
